<?php

declare(strict_types=1);

namespace App\Service;

use App\Job\DemoJob;
use App\Job\LiveRoomDataJob;
use App\Job\LiveRoomSendJob;
use Hyperf\AsyncQueue\Driver\DriverFactory;
use Hyperf\AsyncQueue\Driver\DriverInterface;

class QueueService
{
    protected DriverInterface $driver;

    public function __construct(DriverFactory $driverFactory)
    {
        // 投递通道
        $this->driver = $driverFactory->get('default');
    }

    /**
     * 生产消息.
     * @param mixed $params 数据
     * @param int $delay 延时时间 单位秒
     */
    public function demoPush($params, int $delay = 0): bool
    {
        // 这里的 `DemoJob` 会被序列化存到 Redis 中，所以内部变量最好只传入普通数据
        // 同理，如果内部使用了注解 @Value 会把对应对象一起序列化，导致消息体变大。
        // 所以这里也不推荐使用 `make` 方法来创建 `Job` 对象。
        return $this->driver->push(new DemoJob($params), $delay);
    }

    /**
     * 直播间访问人数增加
     * @param $params
     * @param int $delay
     * @return bool
     */
    public function liveRoomDataPush($params, int $delay = 0): bool
    {
        return $this->driver->push(new LiveRoomDataJob($params), $delay);
    }

    public function liveRoomSendPush(array $params, int $delay = 0): bool
    {
        return $this->driver->push(new LiveRoomSendJob($params), $delay);
    }
}